import { FormPathPattern } from '@formily/shared';
export interface ValidatorOptions {
    validateFirst?: boolean;
    matchStrategy?: (pattern: FormPathPattern, field: any) => boolean;
}
export declare type ValidateNode = (options: ValidateFieldOptions) => Promise<{
    errors: string[];
    warnings: string[];
}>;
export declare type ValidateNodeMap = {
    [key in string]: ValidateNode;
};
export declare type ValidateFormatsMap = {
    [key in string]: RegExp;
};
export declare type InternalFormats = 'url' | 'email' | 'ipv6' | 'ipv4' | 'idcard' | 'taodomain' | 'qq' | 'phone' | 'money' | 'zh' | 'date' | 'zip' | string;
export interface ValidateDescription {
    format?: InternalFormats;
    validator?: CustomValidator;
    required?: boolean;
    pattern?: RegExp | string;
    max?: number;
    maximum?: number;
    exclusiveMaximum?: number;
    exclusiveMinimum?: number;
    minimum?: number;
    min?: number;
    len?: number;
    whitespace?: boolean;
    enum?: any[];
    message?: string;
    [key: string]: any;
}
export declare type ValidateRules = ValidateDescription[];
export declare type ValidateArrayRules = Array<InternalFormats | CustomValidator | ValidateDescription>;
export declare type ValidatePatternRules = InternalFormats | CustomValidator | ValidateDescription | ValidateArrayRules;
export declare type CustomValidator = (value: any, description?: ValidateDescription, rules?: ValidateRulesMap) => ValidateResponse;
export declare type SyncValidateResponse = null | string | boolean | {
    type?: 'error' | 'warning';
    message: string;
};
export declare type ValidateResponse = SyncValidateResponse | AsyncValidateResponse;
export declare type AsyncValidateResponse = Promise<SyncValidateResponse>;
export declare type ValidateRulesMap = {
    [key in string]: (value: any, description: ValidateDescription, rules: ValidateRulesMap) => ValidateResponse | Promise<ValidateResponse>;
};
export interface ValidateFieldOptions {
    first?: boolean;
}
export declare type ValidateCalculator = (validate: (value: any, rules: ValidatePatternRules) => Promise<{
    errors: string[];
    warnings: string[];
}>) => void;
export interface ValidateNodeResult {
    errors: Array<{
        path: string;
        messages: string[];
    }>;
    warnings: Array<{
        path: string;
        messages: string[];
    }>;
}
